@@ -4,7 +4,7 @@
 ;; Base16: (https://github.com/tinted-theming/home)
 
 ;;; Authors:
-;; Scheme: shaunsingh/IBM
+;; Scheme: shaunsingh/IBM, Tinted Theming (https://github.com/tinted-theming)
 ;; Template: Kaleb Elwert <belak@coded.io>
 
 ;;; Code:
@@ -20,12 +20,12 @@
     :base05 "#f2f4f8"
     :base06 "#ffffff"
     :base07 "#08bdba"
-    :base08 "#3ddbd9"
-    :base09 "#78a9ff"
-    :base0A "#ee5396"
-    :base0B "#33b1ff"
-    :base0C "#ff7eb6"
-    :base0D "#42be65"
+    :base08 "#ee5396"
+    :base09 "#ff7eb6"
+    :base0A "#ff6f00"
+    :base0B "#42be65"
+    :base0C "#3ddbd9"
+    :base0D "#33b1ff"
     :base0E "#be95ff"
     :base0F "#82cfff")
   "All colors for Base16 Oxocarbon Dark are defined here.")
